/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

#include "syntax.h"

class MainWindow : public QMainWindow
{
 public:
   MainWindow();

 private:
   Syntax *m_syntaxParser;
   QString loadText();
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 650);

   QWidget *centralWidget = new QWidget(this);
   setCentralWidget(centralWidget);

   QPlainTextEdit *textEdit = new QPlainTextEdit();
   textEdit->setPlainText(loadText());

   QFont font = textEdit->font();
   font.setPointSize(11);
   textEdit->setFont(font);

   QPushButton *pb_close = new QPushButton();
   pb_close->setText("Close");

   QHBoxLayout *layout_text = new QHBoxLayout();
   layout_text->setContentsMargins(20, 15, 20, 0);
   layout_text->addWidget(textEdit);

   QHBoxLayout *layout_pb = new QHBoxLayout();
   layout_pb->addStretch();
   layout_pb->addWidget(pb_close);
   layout_pb->addStretch();

   QVBoxLayout *layout = new QVBoxLayout();
   layout->addLayout(layout_text);
   layout->addSpacing(15);
   layout->addLayout(layout_pb);

   centralWidget->setLayout(layout);

   connect(pb_close, &QPushButton::clicked, this, &QWidget::close);

   m_syntaxParser = new Syntax(textEdit->document());
   m_syntaxParser->processSyntax();
}

QString MainWindow::loadText()
{
   QString retval = "sample text";

   QFile file("../sample.txt");
   bool ok = file.open(QIODevice::ReadOnly);

   if (ok) {
      retval = QString::fromUtf8(file.readAll());
   }

   return retval;
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}

